@@ -5,13 +5,14 @@
 
 ---@diagnostic disable:lowercase-global
 
--- Meta globals:
+-- Meta globals: these are used to keep track of ourselves during the load
+-- process
 MOD_LIST = nil
 MOD = nil
-MOD_NAME = nil
 MOD_DIR = nil
+CURRENT_FILE = nil
 
--- Menu simulations: can't be empty, but cannot be nil
+-- Menu simulations: can be empty, but cannot be nil
 local menu_simulations = {}
 menu_simulations.forest_fire = {}
 menu_simulations.solar_power_construction = {}
@@ -65,11 +66,11 @@ math.pow = math.pow or function(value, power)
     return value ^ power
 end
 
--- maybe create a custom log? Probably excessive, I need a debugger for MY code,
+-- Maybe create a custom log? Probably excessive, I need a debugger for MY code,
 -- not the mod's
 function log(message) end
 
--- Add a prepended message to distinguish which "side" the message came from
+-- Overwrite print to distinguish which "side" the message came from
 local old_print = print
 function print(...)
     old_print("LUA:", ...)
@@ -79,16 +80,23 @@ end
 -- but this should be sufficient for our purposes
 function table_size(t)
     local count = 0
-    for k,v in pairs(t) do
+    for _, _ in pairs(t) do
         count = count + 1
     end
     return count
 end
 
 -- keep track of all mods required in a particular session (do we need this?)
-required_in_session = {}
-paths_in_session = {}
+--required_in_session = {}
+--paths_in_session = {}
 
+-- Standardizes the lua require paths to standardized paths. Removes ".lua" from
+-- the end, replaces all "." with "/", and changes "__modname__..." to
+-- "./factorio-mods/modname/...". Does the same with "__base__" and "__core__",
+-- except they point to "factorio-data" instead of "factorio-mods".
+-- Also returns a boolean `absolute`, which indicates if the filepath is 
+-- considered absolute (from the root mods directory) or local (relative to
+-- CURRENT_FILE)
 local function normalize_module_name(modname)
     -- remove lua from end if present
     modname = modname:gsub(".lua$", "")
@@ -113,14 +121,18 @@ local function normalize_module_name(modname)
     return modname, absolute
 end
 
--- TODO: fix this
+-- Overwrite of require function. Normalizes the module name to make it easier
+-- to interpret later, and manages a number of other things. After preprocessing
+-- has taken place, `old_require` is called and executed at the end of the
+-- function.
 local old_require = require
 function require(module_name)
+    --print("\tcurrent_file:", CURRENT_FILE)
     --print("\trequiring:", module_name)
     local absolute
     module_name, absolute = normalize_module_name(module_name)
     --print("Normalized module name:", module_name, absolute)
-    required_in_session[module_name] = true
+    --required_in_session[module_name] = true
     CURRENT_FILE = module_name
 
     --print(package.path)
@@ -142,113 +154,84 @@ function require(module_name)
     PARENT_DIR = get_parent(module_name)
     --print("PARENT_DIR:", PARENT_DIR)
     --print(paths_in_session[PARENT_DIR])
-    -- local added = false
-    if PARENT_DIR and not paths_in_session[PARENT_DIR] then
+    local added = false
+    --if PARENT_DIR and not paths_in_session[PARENT_DIR] then
+    if PARENT_DIR then
         local with_path = PARENT_DIR .. "/?.lua"
         -- add the mod directory to the path if it's an absolute path
         if not absolute then with_path = MOD_DIR .. "/" .. with_path end
         --print("\tWITH_PATH: " .. with_path)
-        ADD_PATH(with_path)
+        lua_add_path(with_path)
         --print("added path:", with_path)
-        paths_in_session[PARENT_DIR] = true
-        -- added = true
+        --paths_in_session[PARENT_DIR] = true
+        added = true
     end
 
     result = old_require(module_name)
 
-    -- if added then
-    --     REMOVE_PATH()
-    -- end
+    if added then
+        lua_remove_path()
+    end
 
     return result
 end
 
-
-local menu_simulations_searcher = function(modname)
-    -- this doesn't exist, pretend like it does
-    if modname == "./factorio-data/base/menu-simulations/menu-simulations" then
+-- Menu simulations are not included in `factorio-data`; therefore we look for
+-- this path when required and return the dummy values specified earlier above. 
+-- This is done before all other searches, though after `normalize_module_name()`
+local menu_simulations_searcher = function(module_name)
+    if module_name == "./factorio-data/base/menu-simulations/menu-simulations" then
         return (function() return menu_simulations end)
     end
 end
 
 
-function script_path()
-    local str = debug.getinfo(2, "S").source:sub(2)
-   return str:match("(.*[/\\])")
-end
+local archive_searcher = function(module_name)
+    --print("Attempting to find " .. module_name .. " in python:")
 
-local archive_searcher = function(modname)
-    --print("custom_searcher!")
-
-    -- for k, _ in pairs(package.loaded) do
-    --     print(k)
-    -- end
-
-    --print("Attempting to find " .. modname .. " in python:")
-
-    local contents, err = python_require(MOD_LIST, MOD, modname, package.path)
+    local contents, err = python_require(MOD_LIST, MOD, module_name, package.path)
     if contents then
-        filepath = err .. "/?.lua"
-        -- TODO: fix this
-        --ADD_PATH(filepath)
-        return assert(load(contents, modname))
+        return assert(load(contents, module_name))
     else
         return err
     end
 end
 
+-- First, the path is checked if its the menu simulations
 table.insert(package.searchers, 1, menu_simulations_searcher)
--- zip archives are prioritized more than file folders
+-- Then, zip archives are prioritized more than file folders
 table.insert(package.searchers, 2, archive_searcher)
+-- Then the regular `reqiure` load process is followed, preloaded, files, etc.
 
--- we've loaded the mod names and their versions into `python_mods`
--- `python_mods` is still a python object though; here we convert it to a lua table
----@diagnostic disable-next-line:lowercase-global
-mods = {}
-for k in python.iter(python_mods) do
-    mods[k] = python_mods[k]
-end
+-- =================
+-- Interface Helpers
+-- =================
 
--- =========
--- Interface
--- =========
-
--- Alter the package.path to include the directories to search through.
--- We add them to the end to prioritize paths that were added first, such as the
--- core modules
--- NOTE: this might still cause problems in the future; we need some way to only
--- add the root part of the folder we're requesting, otherwise have the chance
--- of requesting a file located in the mod when we should be requesting the core
--- script...
--- I'm kicking this down the road for later though, it works for now
-function ADD_PATH(path)
-    package.path = package.path .. ";" .. path
+-- Alter the package.path to include new directories to search through.
+function lua_add_path(path)
+    package.path = path .. ";" .. package.path
 end
 
 -- Remove the first path from package.path. Make sure not to remove system ones!
--- function REMOVE_PATH()
---     pos = package.path:find(";") + 1
---     package.path = package.path:sub(pos)
--- end
+function lua_remove_path()
+    pos = package.path:find(";") + 1
+    package.path = package.path:sub(pos)
+end
 
 -- (Re)set the package path
-function SET_PATH(path)
+function lua_set_path(path)
     package.path = path
 end
 
-function UNLOAD_SESSION_CACHE()
-    for k, _ in pairs(required_in_session) do
-        package.loaded[k] = nil
-    end
-end
-
-function UNLOAD_ENTIRE_CACHE()
+-- Unloads all files. Lua has a package.preload functionality where files are
+-- only included once and reused as necessary. This can cause problems when two
+-- files have the exact same name however; If mod A has a file named "utils" and
+-- is loaded first, mod B will require "utils" and will get A's copy of the file
+-- instead of loading mod B's copy.
+-- To prevent this, we unload all required files every time we load a stage,
+-- which is excessive but guarantees correct behavior.
+function lua_unload_cache()
     for k, _ in pairs(package.loaded) do
         package.loaded[k] = nil
     end
-end
-
-function RESET_MOD_STATE()
-    required_in_session = {}
-    paths_in_session = {}
 end
\ No newline at end of file
