@@ -4,8 +4,9 @@
 from __future__ import unicode_literals
 
 from draftsman.classes.entity import Entity
-from draftsman.classes.mixins import RequestItemsMixin
+from draftsman.classes.mixins import ModulesMixin, RequestItemsMixin
 from draftsman.error import InvalidItemError
+from draftsman import utils
 from draftsman.warning import (
     DraftsmanWarning,
     ModuleLimitationWarning,
@@ -19,7 +20,7 @@ from draftsman.data import items
 import warnings
 
 
-class Beacon(RequestItemsMixin, Entity):
+class Beacon(ModulesMixin, RequestItemsMixin, Entity):
     """
     An entity designed to apply module effects to other machine's in it's radius.
     """
@@ -35,16 +36,14 @@ class Beacon(RequestItemsMixin, Entity):
                 stacklevel=2,
             )
 
-    def set_item_request(self, item, amount):
+    @utils.reissue_warnings
+    def set_item_request(self, item, count):
         # type: (str, int) -> None
-        """
-        Overwritten
-        """
         # Make sure the item exists
-        if item not in items.raw:
-            raise InvalidItemError("'{}'".format(item))
+        # if item not in items.raw:
+        #     raise InvalidItemError("'{}'".format(item))
 
-        if item not in modules.raw:
+        if item in items.raw and item not in modules.raw:
             warnings.warn(
                 "Item '{}' cannot be placed in Beacon".format(item),
                 ItemLimitationWarning,
@@ -58,4 +57,4 @@ class Beacon(RequestItemsMixin, Entity):
                 stacklevel=2,
             )
 
-        super(Beacon, self).set_item_request(item, amount)
+        super(Beacon, self).set_item_request(item, count)
