@@ -4,7 +4,7 @@
 from __future__ import unicode_literals
 
 from draftsman.classes.entity import Entity
-from draftsman.classes.mixins import DirectionalMixin
+from draftsman.classes.mixins import RequestItemsMixin, DirectionalMixin
 from draftsman.warning import DraftsmanWarning
 
 from draftsman.data.entities import boilers
@@ -12,7 +12,7 @@ from draftsman.data.entities import boilers
 import warnings
 
 
-class Boiler(DirectionalMixin, Entity):
+class Boiler(RequestItemsMixin, DirectionalMixin, Entity):
     """
     An entity that uses a fuel to convert a fluid (usually water) to another
     fluid (usually steam).
