@@ -4,20 +4,17 @@
 from __future__ import unicode_literals
 
 from draftsman.classes.entity import Entity
-from draftsman.classes.mixins import RequestItemsMixin
-from draftsman.error import InvalidItemError
+from draftsman.classes.mixins import ModulesMixin, RequestItemsMixin
+from draftsman import utils
 from draftsman.warning import DraftsmanWarning, ItemLimitationWarning
 
-from draftsman.data.entities import furnaces
-from draftsman.data import entities
-from draftsman.data import modules
-from draftsman.data import recipes
-from draftsman.data import items
+from draftsman.data.entities import furnaces, raw
+from draftsman.data import modules, recipes
 
 import warnings
 
 
-class Furnace(RequestItemsMixin, Entity):
+class Furnace(ModulesMixin, RequestItemsMixin, Entity):
     """
     An entity that takes a fuel and an input item and creates an output item.
     """
@@ -27,7 +24,7 @@ class Furnace(RequestItemsMixin, Entity):
         super(Furnace, self).__init__(name, furnaces, **kwargs)
 
         # Create a set of valid ingredients for this entity
-        crafting_categories = entities.raw[self.name]["crafting_categories"]
+        crafting_categories = raw[self.name]["crafting_categories"]
         total_recipes = []
         for crafting_category in crafting_categories:
             total_recipes.extend(recipes.categories[crafting_category])
@@ -36,6 +33,10 @@ class Furnace(RequestItemsMixin, Entity):
         for name in total_recipes:
             self._valid_input_ingredients.update(recipes.get_recipe_ingredients(name))
 
+        # Get a set of valid fuel items for this entity
+        # self._valid_fuel_items = set()
+        # energy_source = raw[self.name]["energy_source"]
+
         for unused_arg in self.unused_args:
             warnings.warn(
                 "{} has no attribute '{}'".format(type(self), unused_arg),
@@ -58,12 +59,9 @@ class Furnace(RequestItemsMixin, Entity):
 
     # =========================================================================
 
-    def set_item_request(self, item, amount):
+    @utils.reissue_warnings
+    def set_item_request(self, item, count):
         # type: (str, int) -> None
-        # Make sure the item exists
-        if item not in items.raw:
-            raise InvalidItemError(item)
-
         if item not in modules.raw and item not in self.valid_input_ingredients:
             warnings.warn(
                 "Cannot request items that this Furnace doesn't use ({})".format(item),
@@ -71,4 +69,8 @@ class Furnace(RequestItemsMixin, Entity):
                 stacklevel=2,
             )
 
-        return super(Furnace, self).set_item_request(item, amount)
+        # TODO: handle fuel input items
+
+        # self._handle_module_slots(item, count)
+
+        super(Furnace, self).set_item_request(item, count)
