@@ -4,7 +4,11 @@
 from __future__ import unicode_literals
 
 from draftsman.classes.entity import Entity
-from draftsman.classes.mixins import CircuitConnectableMixin, InventoryMixin
+from draftsman.classes.mixins import (
+    RequestItemsMixin,
+    CircuitConnectableMixin,
+    InventoryMixin,
+)
 from draftsman.warning import DraftsmanWarning
 
 from draftsman.data.entities import logistic_active_containers
@@ -12,7 +16,9 @@ from draftsman.data.entities import logistic_active_containers
 import warnings
 
 
-class LogisticActiveContainer(CircuitConnectableMixin, InventoryMixin, Entity):
+class LogisticActiveContainer(
+    InventoryMixin, RequestItemsMixin, CircuitConnectableMixin, Entity
+):
     """
     A logistics container that immediately provides it's contents to the
     logistic network.
