@@ -1,7 +1,5 @@
 # warning.py
 
-# TODO: maybe generic RangeWarning?
-
 """
 Draftsman warnings. Used to enforce "Factorio-correctness".
 """
@@ -36,6 +34,16 @@ class DirectionWarning(DraftsmanWarning):
     pass
 
 
+class FlippingWarning(DraftsmanWarning):
+    """
+    Raised when attempting to flip an entity that may or not be able to be
+    flipped. This is only raised when flipping an :py:class:`EntityCollection`
+    with modded entities.
+    """
+
+    pass
+
+
 class IndexWarning(DraftsmanWarning):
     """
     Raised when the index of some element is out of expected range, though not
@@ -90,6 +98,15 @@ class ItemLimitationWarning(DraftsmanWarning):
     pass
 
 
+class ItemCapacityWarning(DraftsmanWarning):
+    """
+    Raised when an item request exeeds the number of inventory slots of the
+    entity.
+    """
+
+    pass
+
+
 class ModuleLimitationWarning(DraftsmanWarning):
     """
     Raised when the modules inside of an :py:class:`.Entity` conflict, either
